<?php

namespace Btravel\Offices\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Btravel\Offices\Interfaces\OfficeRepositoryInterface;

class OfficePublicController extends BaseController
{
    // use OfficeWorkflow;

    /**
     * Constructor.
     *
     * @param type \Btravel\Office\Interfaces\OfficeRepositoryInterface $office
     *
     * @return type
     */
    public function __construct(OfficeRepositoryInterface $office)
    {
        $this->repository = $office;
        parent::__construct();
    }

    /**
     * Show office's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $offices = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$offices::office.names'))
            ->view('offices::office.index')
            ->data(compact('offices'))
            ->output();
    }


    /**
     * Show office.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $office = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$office->name . trans('offices::office.name'))
            ->view('offices::office.show')
            ->data(compact('office'))
            ->output();
    }

}
