<?php

namespace Btravel\Offices\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Offices\Models\Office;

class OfficePolicy
{

    /**
     * Determine if the given user can view the office.
     *
     * @param UserPolicy $user
     * @param Office $office
     *
     * @return bool
     */
    public function view(UserPolicy $user, Office $office)
    {
        if ($user->canDo('offices.office.view') && $user->isAdmin()) {
            return true;
        }

        return $office->user_id == user_id() && $office->user_type == user_type();
    }

    /**
     * Determine if the given user can create a office.
     *
     * @param UserPolicy $user
     * @param Office $office
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('offices.office.create');
    }

    /**
     * Determine if the given user can update the given office.
     *
     * @param UserPolicy $user
     * @param Office $office
     *
     * @return bool
     */
    public function update(UserPolicy $user, Office $office)
    {
        if ($user->canDo('offices.office.edit') && $user->isAdmin()) {
            return true;
        }

        return $office->user_id == user_id() && $office->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given office.
     *
     * @param UserPolicy $user
     * @param Office $office
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Office $office)
    {
        return $office->user_id == user_id() && $office->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given office.
     *
     * @param UserPolicy $user
     * @param Office $office
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Office $office)
    {
        if ($user->canDo('offices.office.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given office.
     *
     * @param UserPolicy $user
     * @param Office $office
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Office $office)
    {
        if ($user->canDo('offices.office.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
